<!--
 Description: 工作流-我的已办 List
 Author: 作者 liuyh
 Date:   2025-02-27
-->
<template>
  <a-card :bordered="false">
    <!-- 查询区域 -->
    <div class="table-page-search-wrapper">
      <a-form layout="inline" @keyup.enter.native="searchQuery">
        <a-row :gutter="24">
          <a-col :xl="6" :lg="7" :md="8" :sm="24">
            <a-form-item label="流程分类">
              <j-dict-select-tag placeholder="请选择流程分类" v-model="queryParam.category"
                                 dictCode="flow_type"></j-dict-select-tag>
            </a-form-item>
          </a-col>
          <a-col :xl="10" :lg="11" :md="12" :sm="24">
            <a-form-item label="操作时间">
              <j-date :show-time="true" date-format="YYYY-MM-DD HH:mm:ss" placeholder="请选择开始时间"
                      class="query-group-cust"
                      v-model="queryParam.startTime"></j-date>
              <span class="query-group-split-cust"></span>
              <j-date :show-time="true" date-format="YYYY-MM-DD HH:mm:ss" placeholder="请选择结束时间"
                      class="query-group-cust"
                      v-model="queryParam.endTime"></j-date>
            </a-form-item>
          </a-col>
          <a-col :xl="6" :lg="7" :md="8" :sm="24">
            <span style="float: left;overflow: hidden;" class="table-page-search-submitButtons">
              <a-button type="primary" @click="searchQuery" icon="search">查询</a-button>
              <a-button @click="searchReset" icon="reload" style="margin-left: 8px">重置</a-button>
            </span>
          </a-col>
        </a-row>
      </a-form>
    </div>
    <!-- 查询区域-END -->

    <!-- table区域-begin -->
    <div>

      <a-table
        ref="table"
        size="middle"
        :scroll="{x:true}"
        bordered
        rowKey="id"
        :columns="columns"
        :dataSource="dataSource"
        :pagination="ipagination"
        :loading="loading"
        class="j-table-force-nowrap"
        @change="handleTableChange">

        <span slot="action" slot-scope="text, record">
            <a @click="handelDetial(record,text)">详情</a>
        </span>

      </a-table>
    </div>
  </a-card>
</template>

<script>

import '@/assets/less/TableExpand.less'
import { mixinDevice } from '@/utils/mixin'
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import JDictSelectTag from '@/components/dict/JDictSelectTag.vue'
export default {
  name: 'NcDeviceCharactersList',
  mixins: [JeecgListMixin, mixinDevice],
  components: {
    JDictSelectTag,
  },
  data() {
    return {
      description: '工作流-已办',
      // 表头
      columns: [
        {
          title: '序号',
          dataIndex: '',
          key: 'rowIndex',
          width: 200,
          align: 'center',
          customRender: function(t, r, index) {
            return parseInt(index) + 1
          }
        },
        {
          title: '流程分类',
          align: 'center',
          dataIndex: 'category_dictText',
          width: 200
        },
        {
          title: '流程名称',
          align: 'center',
          dataIndex: 'procDefName',
          width: 200
        },
        {
          title: '流程业务简要描述',
          align: 'center',
          dataIndex: 'description',
          width: 300
        },
        {
          title: '流程发起人名称',
          align: 'center',
          dataIndex: 'proposer_dictText',
          width: 250
        },
        {
          title: '任务名称',
          align: 'center',
          dataIndex: 'taskName',
          width: 250
        },
        {
          title: '操作时间',
          align: 'center',
          dataIndex: 'finishTime',
          width: 300
        },
        {
          title: '操作',
          dataIndex: 'action',
          scopedSlots: { customRender: 'action' },
          align: 'center',
          width: 200,
          fixed: 'right'
        }
      ],
      url: {
        list: '/assign/flow/finishedList'
      },
      dictOptions: {},
      selectShenpiData: {},
      selectDispatchFileXqData: {},
      selectWeekMaintenanceData: {},
      selectInspectionOrderXqData: {},
      selectRepairOrderData: {},
      selectOutBoundOrderData: {},
      selectLossBoundOrderData: {},
      selectStocktakingBoundOrderData: {}
    }
  },
  created() {
  },
  computed: {
    importExcelUrl: function() {
      return `${window._CONFIG['domianURL']}/${this.url.importExcelUrl}`
    }
  },
  methods: {
    handelDetial(item, index) {
      console.log('点击了详情')
      console.log('item----->', item)
      console.log('index----->', index)
      let approcesstype = this.splitAprocessType(item.category)
      console.log('approcesstype--->', approcesstype)
      switch (approcesstype) {
        case 'drApproval':
          this.handDrDetial(item)
          break
        case 'ggApproval':
          this.handDispatchFileDetial(item)
          break
        case 'sbdjApproval':
          this.handInspectionOrder(item)
          break
        case 'WEEK_MAINTENANCE':
          this.handleWeekMaintenance(item)
          break
        case 'eam_repair':
          this.handleRepairOrder(item)
          break
        case 'toolOutStorageApproval':
          this.handleToolOutStorageApproval(item)
          break
        case 'toolsStocktakingBound':
          this.handleToolStocktakingApproval(item)
          break
        case 'toolsLossApproval':
          this.handleToolLossApproval(item)
          break
        default:
          alert('没找到该流程')
      }
    },

    splitAprocessType(title) {
      let parts = title.split('：') // 注意冒号是全角字符，使用对应的字进行分割
      let result = parts[0]
      return result
    },
    handDrDetial(item) {
      this.selectShenpiData = item
      this.selectShenpiData.assignee_dictText = item.todoUsers_dictText
      this.selectShenpiData.procInstId = item.procInsId
      this.selectShenpiData.title = item.description
      this.$refs.modalFormApproval.clearTableSource()
      this.$refs.modalFormApproval.getAllApproveData(item)
    },
    handDispatchFileDetial(item) {
      console.log('item----->', item)
      this.selectDispatchFileXqData = item
      this.selectDispatchFileXqData.assignee_dictText = item.todoUsers_dictText
      this.selectDispatchFileXqData.procInstId = item.procInsId
      this.selectDispatchFileXqData.processInstanceId = item.procInsId
      this.selectDispatchFileXqData.title = item.description
      this.$refs.modalFormDispatchFileXq.clearTableSource()
      this.$refs.modalFormDispatchFileXq.getAllApproveData(item)
    },
    handleWeekMaintenance(record) {
      this.selectWeekMaintenanceData = Object.assign({}, record)
      this.$refs.weekMaintenanceApprovalModal.handleDetail(record)
      this.$refs.weekMaintenanceApprovalModal.title = '详情'
      this.$refs.weekMaintenanceApprovalModal.disableSubmit = true
    },

    handInspectionOrder(record) {
      console.log('record----->', record)
      this.selectInspectionOrderXqData = Object.assign({}, record)
      const { todoUsers_dictText, procInsId, description, taskName } = this.selectInspectionOrderXqData
      this.selectInspectionOrderXqData.assignee_dictText = todoUsers_dictText
      this.selectInspectionOrderXqData.procInstId = procInsId
      this.selectInspectionOrderXqData.processInstanceId = procInsId
      this.selectInspectionOrderXqData.title = description
      this.$refs.modalFormInspectionOrderXq.visible = true
      this.$refs.modalFormInspectionOrderXq.title = taskName
      this.$refs.modalFormInspectionOrderXq.disableSubmit = true
      this.$refs.modalFormInspectionOrderXq.getAllApproveData({
        ...record,
        procInstId: procInsId,
        processInstanceId: procInsId
      })
      this.$refs.modalFormInspectionOrderXq.getBasicInformation(record)
    },

    /**
     * 点击设备维修分类流程详情时触发
     * @param record
     */
    handleRepairOrder(record) {
      this.selectRepairOrderData = Object.assign({}, record)
      const { procInsId, taskName } = this.selectRepairOrderData
      this.$refs.repairOrderApprovalModal.visible = true
      this.$refs.repairOrderApprovalModal.disableSubmit = true
      this.$refs.repairOrderApprovalModal.title = taskName
      this.$refs.modalFormInspectionOrderXq.getAllApproveData({
        ...record,
        procInstId: procInsId,
        processInstanceId: procInsId
      })
      this.$refs.repairOrderApprovalModal.getBasicInformation(record)
    },

    handleToolOutStorageApproval(item) {
      this.selectOutBoundOrderData = Object.assign({}, item)
      item.procInstId = item.procInsId
      item.processInstanceId = item.procInsId
      this.selectOutBoundOrderData.assignee_dictText = item.todoUsers_dictText
      this.$refs.outBoundOrderHandle.auditVisible = false
      this.$refs.outBoundOrderHandle.clearTableSource()
      this.$refs.outBoundOrderHandle.getAllApproveData(item)
    },

    handleToolStocktakingApproval(item) {

      this.selectStocktakingBoundOrderData = Object.assign({}, item)
      item.procInstId = item.procInsId
      item.processInstanceId = item.procInsId
      this.selectStocktakingBoundOrderData.assignee_dictText = item.todoUsers_dictText
      this.$refs.stocktakingBoundHandle.auditVisible = false
      this.$refs.stocktakingBoundHandle.disableSubmit = true
      this.$refs.stocktakingBoundHandle.clearTableSource()
      this.$refs.stocktakingBoundHandle.getAllApproveData(item)

    },
    handleToolLossApproval(item) {
      this.selectLossBoundOrderData = Object.assign({}, item)
      item.procInstId = item.procInsId
      item.processInstanceId = item.procInsId
      this.selectStocktakingBoundOrderData.assignee_dictText = item.todoUsers_dictText
      this.$refs.lossBoundHandle.auditVisible = false
      this.$refs.lossBoundHandle.disableSubmit = true
      this.$refs.lossBoundHandle.clearTableSource()
      this.$refs.lossBoundHandle.getAllApproveData(item)

    }
  }
}
</script>
<style scoped>
@import '~@assets/less/common.less';
</style>